@@ -1,11 +1,17 @@
-from conans.model.options import Options, PackageOptions, OptionsValues
-from conans.model.requires import Requirements
-from conans.model.build_info import DepsCppInfo
-from conans import tools  # @UnusedImport KEEP THIS! Needed for pyinstaller to copy to exe.
-from conans.errors import ConanException
-from conans.model.env_info import DepsEnvInfo, EnvValues
 import os
+from contextlib import contextmanager
 
+import six
+
+from conans.client import tools
+from conans.client.output import ScopedOutput
+from conans.client.tools.env import environment_append, no_op, pythonpath
+from conans.client.tools.oss import OSInfo
+from conans.errors import ConanException, ConanInvalidConfiguration
+from conans.model.build_info import DepsCppInfo
+from conans.model.env_info import DepsEnvInfo
+from conans.model.options import Options, OptionsValues, PackageOptions
+from conans.model.requires import Requirements
 from conans.model.user_info import DepsUserInfo
 from conans.paths import RUN_LOG_NAME
 
@@ -17,13 +23,13 @@ def create_options(conanfile):
 
         default_options = getattr(conanfile, "default_options", None)
         if default_options:
-            if isinstance(default_options, (list, tuple)):
+            if isinstance(default_options, (list, tuple, dict)):
                 default_values = OptionsValues(default_options)
-            elif isinstance(default_options, str):
+            elif isinstance(default_options, six.string_types):
                 default_values = OptionsValues.loads(default_options)
             else:
-                raise ConanException("Please define your default_options as list or "
-                                     "multiline string")
+                raise ConanException("Please define your default_options as list, "
+                                     "multiline string or dictionary")
             options.values = default_values
         return options
     except Exception as e:
@@ -38,7 +44,7 @@ def create_requirements(conanfile):
         else:
             if not conanfile.requires:
                 return Requirements()
-            if isinstance(conanfile.requires, tuple):
+            if isinstance(conanfile.requires, (tuple, list)):
                 return Requirements(*conanfile.requires)
             else:
                 return Requirements(conanfile.requires, )
@@ -55,25 +61,22 @@ def create_settings(conanfile, settings):
         settings.constraint(current)
         return settings
     except Exception as e:
-        raise ConanException("Error while initializing settings. %s" % str(e))
+        raise ConanInvalidConfiguration("Error while initializing settings. %s" % str(e))
 
 
-def create_exports(conanfile):
-    if not hasattr(conanfile, "exports"):
-        return None
-    else:
-        if isinstance(conanfile.exports, str):
-            return (conanfile.exports, )
-        return conanfile.exports
+@contextmanager
+def _env_and_python(conanfile):
+    with environment_append(conanfile.env):
+        with pythonpath(conanfile):
+            yield
 
 
-def create_exports_sources(conanfile):
-    if not hasattr(conanfile, "exports_sources"):
-        return None
-    else:
-        if isinstance(conanfile.exports_sources, str):
-            return (conanfile.exports_sources, )
-        return conanfile.exports_sources
+def get_env_context_manager(conanfile, without_python=False):
+    if not conanfile.apply_env:
+        return no_op()
+    if without_python:
+        return environment_append(conanfile.env)
+    return _env_and_python(conanfile)
 
 
 class ConanFile(object):
@@ -87,21 +90,57 @@ class ConanFile(object):
     # change the actual license of the source code
     license = None
     author = None  # Main maintainer/responsible for the package, any format
+    description = None
+    topics = None
+    homepage = None
     build_policy = None
     short_paths = False
+    apply_env = True  # Apply environment variables from requires deps_env_info and profiles
+    exports = None
+    exports_sources = None
+    generators = ["txt"]
+    revision_mode = "hash"
 
-    def __init__(self, output, runner, settings, conanfile_directory, user=None, channel=None):
-        # User defined generators
-        self.generators = self.generators if hasattr(self, "generators") else ["txt"]
+    # Vars to control the build steps (build(), package())
+    should_configure = True
+    should_build = True
+    should_install = True
+    should_test = True
+    in_local_cache = True
+    develop = False
+
+    # Defaulting the reference fields
+    default_channel = None
+    default_user = None
+
+    # Settings and Options
+    settings = None
+    options = None
+    default_options = None
+
+    def __init__(self, output, runner, display_name="", user=None, channel=None):
+        # an output stream (writeln, info, warn error)
+        self.output = ScopedOutput(display_name, output)
+        self.display_name = display_name
+        # something that can run commands, as os.sytem
+        self._conan_runner = runner
+        self._conan_user = user
+        self._conan_channel = channel
+
+        self.compatible_packages = []
+
+    def initialize(self, settings, env):
         if isinstance(self.generators, str):
             self.generators = [self.generators]
-
         # User defined options
         self.options = create_options(self)
         self.requires = create_requirements(self)
         self.settings = create_settings(self, settings)
-        self.exports = create_exports(self)
-        self.exports_sources = create_exports_sources(self)
+
+        if 'cppstd' in self.settings.fields:
+            self.output.warn("Setting 'cppstd' is deprecated in favor of 'compiler.cppstd',"
+                             " please update your recipe.")
+
         # needed variables to pack the project
         self.cpp_info = None  # Will be initialized at processing time
         self.deps_cpp_info = DepsCppInfo()
@@ -115,36 +154,16 @@ class ConanFile(object):
         # Keys are the package names, and the values a dict with the vars
         self.deps_user_info = DepsUserInfo()
 
-        self.copy = None  # initialized at runtime
-
-        # an output stream (writeln, info, warn error)
-        self.output = output
-        # something that can run commands, as os.sytem
-        self._runner = runner
-
-        self.conanfile_directory = conanfile_directory
-        self._scope = None
-
-        self.develop = False
-
         # user specified env variables
-        self._env_values = EnvValues()  # Updated at runtime, user specified -e
-        self._user = user
-        self._channel = channel
-
-        # Are we in local cache? Suggest a better name
-        self.in_local_cache = False
-
-        # Init a description
-        self.description = None
+        self._conan_env_values = env.copy()  # user specified -e
 
     @property
     def env(self):
-        """Apply the self.deps_env_info into a copy of self._env_values (will prioritize the
-        self._env_values, user specified from profiles or -e first, then inherited)"""
+        """Apply the self.deps_env_info into a copy of self._conan_env_values (will prioritize the
+        self._conan_env_values, user specified from profiles or -e first, then inherited)"""
         # Cannot be lazy cached, because it's called in configure node, and we still don't have
         # the deps_env_info objects available
-        tmp_env_values = self._env_values.copy()
+        tmp_env_values = self._conan_env_values.copy()
         tmp_env_values.update(self.deps_env_info)
 
         ret, multiple = tmp_env_values.env_dicts(self.name)
@@ -153,35 +172,25 @@ class ConanFile(object):
 
     @property
     def channel(self):
-        if not self._channel:
-            self._channel = os.getenv("CONAN_CHANNEL")
-            if not self._channel:
-                raise ConanException("CONAN_CHANNEL environment variable not defined, "
-                                     "but self.channel is used in conanfile")
-        return self._channel
+        if not self._conan_channel:
+            self._conan_channel = os.getenv("CONAN_CHANNEL") or self.default_channel
+            if not self._conan_channel:
+                raise ConanException("channel not defined, but self.channel is used in conanfile")
+        return self._conan_channel
 
     @property
     def user(self):
-        if not self._user:
-            self._user = os.getenv("CONAN_USERNAME")
-            if not self._user:
-                raise ConanException("CONAN_USERNAME environment variable not defined, "
-                                     "but self.user is used in conanfile")
-        return self._user
+        if not self._conan_user:
+            self._conan_user = os.getenv("CONAN_USERNAME") or self.default_user
+            if not self._conan_user:
+                raise ConanException("user not defined, but self.user is used in conanfile")
+        return self._conan_user
 
-    def collect_libs(self, folder="lib"):
-        self.output.warn("Use 'self.collect_libs' is deprecated, "
-                         "use tools.collect_libs(self) instead")
+    def collect_libs(self, folder=None):
+        self.output.warn("'self.collect_libs' is deprecated, "
+                         "use 'tools.collect_libs(self)' instead")
         return tools.collect_libs(self, folder=folder)
 
-    @property
-    def scope(self):
-        return self._scope
-
-    @scope.setter
-    def scope(self, value):
-        self._scope = value
-
     @property
     def build_policy_missing(self):
         return self.build_policy == "missing"
@@ -217,35 +226,55 @@ class ConanFile(object):
         """
 
     def build(self):
+        """ build your project calling the desired build tools as done in the command line.
+        E.g. self.run("cmake --build .") Or use the provided build helpers. E.g. cmake.build()
+        """
         self.output.warn("This conanfile has no build step")
 
     def package(self):
+        """ package the needed files from source and build folders.
+        E.g. self.copy("*.h", src="src/includes", dst="includes")
+        """
         self.output.warn("This conanfile has no package step")
 
     def package_info(self):
         """ define cpp_build_info, flags, etc
         """
 
-    def run(self, command, output=True, cwd=None):
-        """ runs such a command in the folder the Conan
-        is defined
-        """
-        retcode = self._runner(command, output, os.path.abspath(RUN_LOG_NAME),  cwd)
-        if retcode != 0:
+    def run(self, command, output=True, cwd=None, win_bash=False, subsystem=None, msys_mingw=True,
+            ignore_errors=False, run_environment=False, with_login=True):
+        def _run():
+            if not win_bash:
+                return self._conan_runner(command, output, os.path.abspath(RUN_LOG_NAME), cwd)
+            # FIXME: run in windows bash is not using output
+            return tools.run_in_windows_bash(self, bashcmd=command, cwd=cwd, subsystem=subsystem,
+                                             msys_mingw=msys_mingw, with_login=with_login)
+        if run_environment:
+            with tools.run_environment(self):
+                if OSInfo().is_macos:
+                    command = 'DYLD_LIBRARY_PATH="%s" DYLD_FRAMEWORK_PATH="%s" %s' % \
+                              (os.environ.get('DYLD_LIBRARY_PATH', ''),
+                               os.environ.get("DYLD_FRAMEWORK_PATH", ''),
+                               command)
+                retcode = _run()
+        else:
+            retcode = _run()
+
+        if not ignore_errors and retcode != 0:
             raise ConanException("Error %d while executing %s" % (retcode, command))
 
+        return retcode
+
     def package_id(self):
-        """ modify the conans info, typically to narrow values
-        eg.: conaninfo.package_references = []
+        """ modify the binary info, typically to narrow values
+        e.g.: self.info.settings.compiler = "Any" => All compilers will generate same ID
         """
 
     def test(self):
+        """ test the generated executable.
+        E.g.  self.run("./example")
+        """
         raise ConanException("You need to create a method 'test' in your test/conanfile.py")
 
     def __repr__(self):
-        if self.name and self.version and self._channel and self._user:
-            return "%s/%s@%s/%s" % (self.name, self.version, self.user, self.channel)
-        elif self.name and self.version:
-            return "%s/%s@PROJECT" % (self.name, self.version)
-        else:
-            return "PROJECT"
+        return self.display_name
